selectors
open | /demo/selectors.html |
click | parentnodenotok |
pause | 1000 |
assertText | parentnodeok | Click me!
click | parentnodeok |
waitForText | target | ok
assertText | target | ok
click | parentnodechain |
waitForText | css=#nesteddivs0 div.inserted | selected
assertText | css=#nesteddivs1 div.inserted | selected
assertText | css=#nesteddivs0 div.inserted | selected
assertText | css=#nesteddivs2 div.inserted | selected